@@ -46,14 +46,10 @@ class SeleniumConfig:
             chrome_options.add_argument(proxy_server.http_proxy)
 
         chrome_options.set_capability('goog:loggingPrefs', {'browser': 'ALL', 'performance': 'ALL'})
-        chrome_options.set_capability('goog:chromeOptions', {'args': ['--incognito',
-                                                                      '--start-maximized',
-                                                                      '--no-sandbox',
-                                                                      '--disable-dev-shm-usage']})
-        chrome_options.set_capability('chromeOptions', {'args': ['--incognito',
-                                                                 '--start-maximized',
-                                                                 '--no-sandbox',
-                                                                 '--disable-dev-shm-usage']})
+        chrome_options.add_argument('incognito')
+        chrome_options.add_argument('disable-dev-shm-usage')
+        chrome_options.add_argument('no-sandbox')
+        chrome_options.add_argument('window-size=1359,901')
 
         if not remote:
             self.driver = webdriver.Chrome(service=Service(ChromeDriverManager().install()), options=chrome_options)
@@ -77,7 +73,6 @@ class SeleniumConfig:
 
         :Returns:
              - the driver object"""
-        self.driver.maximize_window()
         self.driver.get(url)
 
     def vget_url(self, url, proof: str, last):
